@@ -5,15 +5,14 @@ knitr::opts_chunk$set(
 )
 
 ## -----------------------------------------------------------------------------
-# Load the RGtk2 library
-library(RGtk2)
+# Load the tcltk package
+library(tcltk)
 
 
 ## -----------------------------------------------------------------------------
-# Load the following libraries.
-library(raster)
-library(rgdal)
-library(sp)
+# Load the following packages.
+library(tcltk2)
+library(terra)
 library(sara4r)
 
 ## -----------------------------------------------------------------------------
